@@ -1,4 +1,4 @@
-use crate::models::BlockRpcResponse;
+use crate::models::{BlockRpcResponse, TransactionRpcResponse};
 use primitive_types::{H256, U256};
 use serde::Deserialize;
 
@@ -23,3 +23,8 @@ pub(crate) struct ResponseWrapperForBytes {
 pub(crate) struct ResponseWrapperForBlock {
     pub result: BlockRpcResponse,
 }
+
+#[derive(Deserialize)]
+pub(crate) struct ResponseWrapperForTransaction {
+    pub result: TransactionRpcResponse,
+}
